@@ -31,7 +31,7 @@ function(data, Ns, alternative, int, doublePvalue, delta, reject.alpha){
   if (alternative == "two.sided" && delta != 0) {
     moreExtremeMat <- csmTemp2sidedDelta(data, moreExtremeMat, Ns, int, alternative, lookupArray, doublePvalue, delta, reject.alpha, checkPrev = TRUE, prevMoreExtremeMat)
   } else {
-    moreExtremeMat <- csmTemp(data, moreExtremeMat, Ns, int, alternative, lookupArray, doublePvalue, reject.alpha, checkPrev = TRUE, prevMoreExtremeMat)
+    moreExtremeMat <- csmTemp(data, moreExtremeMat, Ns, int, alternative, lookupArray, doublePvalue, delta, reject.alpha, checkPrev = TRUE, prevMoreExtremeMat)
   }
   # If moreExtremeMat is just FALSE, then return FALSE
   if (isFALSE(moreExtremeMat)) { return(moreExtremeMat) }
